; Some Moon based astronomical times and data for Gcal-2.20 or newer
;
; $Id: mdata.rc 0.07 2000/06/30 00:00:07 tom Exp $
;
; Copyright (c) 2000   Thomas Esken      <esken@gmx.net>
;                      Im Hagenfeld 84
;                      D-48147 M"unster
;                      GERMANY
;
; This software doesn't claim completeness, correctness or usability.
; On principle I will not be liable for ANY damages or losses (implicit
; or explicit), which result from using or handling my software.
; If you use this software, you agree without any exception to this
; agreement, which binds you LEGALLY !!
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the `GNU General Public License' as published by
; the `Free Software Foundation'; either version 3, or (at your option)
; any later version.
;
; You should have received a copy of the `GNU General Public License'
; along with this program; if not, write to the:
;
;
;
; Try this resource file by using the  `-QUx'  option of Gcal.
; Try `--time-offset=ARG' to calculate some data for a definite time!
; Try `--precise' to display data and times more precise!
;
; Either set your preferred geographical base location here
; or comment the proper next lines and run Gcal with the `--text-variable=ARG'
; option for passing the geographical base location in a flexible manner like:
;
;   gcal -f./mdata.rc -QUx --text-var='$l=Münster:$c=+5158+00738+61:$z=60' --time-offset=t
;
; *** If you modify this file you have to rename the modified version.
; *** If you make any improvements I would like to hear from you.
; *** But I do not promise any support.
;
;
; Name of location
; $l=%3%1Münster%2
; Geographical co-ordinate of location
; $c=+5158+00738+61
; Timezone of location
; $z=60
;
; Line templates
$p=0*d1#999
;
$l=
$c=
$z=
;
; Data.
$p A00 calculations for geographic co-ordinate          $c,$z/$l
$p A01 gmt time and date                                %@
$p A02 local time and date                              %t /%n
$p A03 given time-offset                                %(x$c
$p A04 local julian date            at %<9*(x$c         %(y$c,$z
$p A05 local julian ephemeris date  at %<9*(x$c         %(z$c,$z
$p A06 local sidereal time          at %<9*(x$c         %(w$c,$z
$p A07 delta-t in ss.fract          at %<9*(x$c         %(v$c,$z
;
$p B00 T moon/earth dist in radii   at %<9*(x$c         %(g$c,$z
$p B01 T moon/earth dist in km      at %<9*(x$c         %(*g$c,$z
$p B02 T moon's ecliptic longitude  at %<9*(x$c         %(d$c,$z
$p B03 T moon's ecliptic latitude   at %<9*(x$c         %(e$c,$z
$p B04 T moon's right ascension     at %<9*(x$c         %(f$c,$z
$p B05 T moon's declination angle   at %<9*(x$c         %(c$c,$z
$p B06 T moon's azimuth angle       at %<9*(x$c         %(b$c,$z
$p B07 T moon's elevation angle     at %<9*(x$c         %(a$c,$z
$p B08 T moon's horizontal parallax at %<9*(x$c         %(*6$c,$z
$p B09 T moon's semidiameter        at %<9*(x$c         %(*7$c,$z
$p B10 T moon's magnitude           at %<9*(x$c         %(8$c,$z
$p B11 T moon's phase angle         at %<9*(x$c         %(9$c,$z
$p B12 T moon/sun elongation        at %<9*(x$c         %(h$c,$z
$p B13 T moon/sun azimuth delta     at %<9*(x$c         %(B$c,$z
$p B14 T moon/sun elevation delta   at %<9*(x$c         %(A$c,$z
$p B15 T atmospheric refraction     at %<9*(x$c         %(*i$c,$z
;
$p C00 G moon/earth dist in radii   at %<9*(x$c         %(t$c,$z
$p C01 G moon/earth dist in km      at %<9*(x$c         %(*t$c,$z
$p C02 G moon's ecliptic longitude  at %<9*(x$c         %(q$c,$z
$p C03 G moon's ecliptic latitude   at %<9*(x$c         %(r$c,$z
$p C04 G moon's right ascension     at %<9*(x$c         %(s$c,$z
$p C05 G moon's declination angle   at %<9*(x$c         %(p$c,$z
$p C06 G moon's azimuth angle       at %<9*(x$c         %(o$c,$z
$p C07 G moon's elevation angle     at %<9*(x$c         %(n$c,$z
$p C08 G moon's horizontal parallax at %<9*(x$c         %(*j$c,$z
$p C09 G moon's semidiameter        at %<9*(x$c         %(*k$c,$z
$p C10 G moon's magnitude           at %<9*(x$c         %(l$c,$z
$p C11 G moon's phase angle         at %<9*(x$c         %(m$c,$z
$p C12 G moon/sun elongation        at %<9*(x$c         %(u$c,$z
$p C13 G moon/sun azimuth delta     at %<9*(x$c         %(D$c,$z
$p C14 G moon/sun elevation delta   at %<9*(x$c         %(C$c,$z
;
$p DM0 moon's midnight (near lowest culmination) at     %(0$c,$z
$p DM2 T moon's elevation angle     at moon's midnight  %(L$c,$z
$p DM3 T moon's phase angle         at moon's midnight  %(M$c,$z
$p DM4 G moon's elevation angle     at moon's midnight  %(S$c,$z
$p DM5 G moon's phase angle         at moon's midnight  %(T$c,$z
$p DM6 moon/sun midnight delta                          %(I$c,$z
$p DN1 moon's noon (near highest culmination) at        %)1$c,$z
$p DN2 T moon's elevation angle     at moon's noon      %)N$c,$z
$p DN3 T moon's phase angle         at moon's noon      %)O$c,$z
$p DN4 G moon's elevation angle     at moon's noon      %)U$c,$z
$p DN5 G moon's phase angle         at moon's noon      %)V$c,$z
$p DN6 moon/sun noon delta                              %)J$c,$z
;
$p ER0 moon's upper limb (standard rise) rises at       %(5$c,$z
$p ER3 T moon's azimuth angle       at moon's rise      %(Q$c,$z
$p ER4 T moon's elevation angle     at moon's rise      %(P$c,$z
$p ER5 T moon's phase angle         at moon's rise      %(R$c,$z
$p ER6 G moon's azimuth angle       at moon's rise      %(X$c,$z
$p ER7 G moon's elevation angle     at moon's rise      %(W$c,$z
$p ER8 G moon's phase angle         at moon's rise      %(Y$c,$z
$p ER9 T moon/sun azimuth delta     at moon's rise      %(F$c,$z
$p ERA T moon/sun elevation delta   at moon's rise      %(E$c,$z
$p ERB G moon/sun azimuth delta     at moon's rise      %(H$c,$z
$p ERC G moon/sun elevation delta   at moon's rise      %(G$c,$z
$p ERD moon/sun standard rise delta                     %(K$c,$z
$p FR0 moon's center rises at                           %(4$c,$z
$p GR0 moon's upper limb at math-horizon rises at       %(3$c,$z
$p HR0 moon's center at math-horizon rises at           %(2$c,$z
;
$p HS1 moon's center at math-horizon sets at            %)2$c,$z
$p GS1 moon's upper limb at math-horizon sets at        %)3$c,$z
$p FS1 moon's center sets at                            %)4$c,$z
$p ES1 moon's upper limb (standard set) sets at         %)5$c,$z
$p ES3 T moon's azimuth angle       at moon's set       %)Q$c,$z
$p ES4 T moon's elevation angle     at moon's set       %)P$c,$z
$p ES5 T moon's phase angle         at moon's set       %)R$c,$z
$p ES6 G moon's azimuth angle       at moon's set       %)X$c,$z
$p ES7 G moon's elevation angle     at moon's set       %)W$c,$z
$p ES8 G moon's phase angle         at moon's set       %)Y$c,$z
$p ES9 T moon/sun azimuth delta     at moon's set       %)F$c,$z
$p ESA T moon/sun elevation delta   at moon's set       %)E$c,$z
$p ESB G moon/sun azimuth delta     at moon's set       %)H$c,$z
$p ESC G moon/sun elevation delta   at moon's set       %)G$c,$z
$p ESD moon/sun standard set delta                      %)K$c,$z
;
$p QE6 moon's upper limb (standard r/s) visible         %[5$c,$z
$p QE7 moon's upper limb (standard r/s) non-visible     %]5$c,$z
$p QF6 moon's center visible                            %[4$c,$z
$p QF7 moon's center non-visible                        %]4$c,$z
$p QG6 math-horizon moon's upper limb visible           %[3$c,$z
$p QG7 math-horizon moon's upper limb non-visible       %]3$c,$z
$p QH6 math-horizon moon's center visible               %[2$c,$z
$p QH7 math-horizon moon's center non-visible           %]2$c,$z
