; One column world time table with sunset/sunrise etc. for Gcal-2.20 or newer
;
; $Id: wtt3.rc 0.01 2000/03/05 00:00:01 tom Exp $
;
; Copyright (c) 2000   Thomas Esken      <esken@uni-muenster.de>
;                      Im Hagenfeld 84
;                      D-48147 M"unster
;                      GERMANY
;
; This software doesn't claim completeness, correctness or usability.
; On principle I will not be liable for ANY damages or losses (implicit
; or explicit), which result from using or handling my software.
; If you use this software, you agree without any exception to this
; agreement, which binds you LEGALLY !!
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the `GNU General Public License' as published by
; the `Free Software Foundation'; either version 3, or (at your option)
; any later version.
;
; You should have received a copy of the `GNU General Public License'
; along with this program; if not, write to the:
;
;
;
; Try this resource file by using the  `-QUx'  option of Gcal.
;
; *** If you modify this file you have to rename the modified version.
; *** If you make any improvements I would like to hear from you.
; *** But I do not promise any support.
;
; Either set `$f' to `%@' or to `%@*'
;   for displaying using the 12-hours time format.
;
$f=%@
;$f=%@*
;
; The line templates.
;
$p=0*d1#999
$a=$f$t  %o$c,$t rise,%s$c,$t set %u$c,$t day,%z$c,$t night  $l
;
; The locations.
;
$l=Samoa
$c=-1350-17144
$t=-660
$p $a
;
$l=Honolulu
$c=+211825-1575130
$t=-600
$p $a
;
$l=Anchorage
$c=+611305-1495401
$t=-540
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=San Francisco
$c=+3747-12230
$t=-480
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Denver
$c=+394421-1045903
$t=-420
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Managua
$c=+1206-08620
$t=-300
$p $a
;
$l=Chicago
$c=+415100-0873900
$t=-360
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Montreal
$c=+4531-07334
$t=-300
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=New York
$c=+404251-0740023
$t=-300
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Bermuda
$c=+3217-06446
$t=-240
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Rio de Janeiro
$c=-2300-04312
$t=-180
a=02sat2
b=10sun1
$p %i0@a#0@b-1 $a
$t+=60
$p %e0@a#0@b-1 $a
;
$l=Azores
$c=+3744-02540
$t=-60
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Dakar
$c=+1440-01726
$t=0
$p $a
;
$l=London
$c=+512830-0001845
$t=0
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Lisbon
$c=+3843-00908
$t=0
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=%3%1Münster%2
$c=+5158+00738
$t=60
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Madrid
$c=+4024-00341
$t=60
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Stockholm
$c=+5920+01803
$t=60
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Johannesburg
$c=-2615+02800
$t=120
$p $a
;
$l=Istanbul
$c=+4101+02858
$t=120
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Helsinki
$c=+6010+02458
$t=120
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Athens
$c=+3758+02343
$t=120
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Nairobi
$c=-0117+03649
$t=180
$p $a
;
$l=Moscow
$c=+5545+03735
$t=180
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Tehran
$c=+3540+05126
$t=210
a=0321
b=0922
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Bombay
$c=+1855+07250
$t=330
$p $a
;
$l=Bangkok
$c=+1345+10035
$t=420
$p $a
;
$l=Beijing
$c=+3955+11620
$t=480
$p $a
;
$l=Hongkong
$c=+2217+11409
$t=480
$p $a
;
$l=Tokyo
$c=+3542+13946
$t=540
$p $a
;
$l=Seoul
$c=+3733+12658
$t=540
$p $a
;
$l=Sydney
$c=-3352+15113
$t=600
a=03sun9
b=10sun9
$p %i0@a#0@b-1 $a
$t+=60
$p %e0@a#0@b-1 $a
;
$l=Wellington
$c=-4119+17446
$t=720
a=03sun3
b=10sun1
$p %i0@a#0@b-1 $a
$t+=60
$p %e0@a#0@b-1 $a
