;
; meteoric.rc -- gcal sample resource file
;
; Meteorstr"ome -- Code/Zeitraum/Maximum/Anzahl/Radiant/Geschwindigkeit/Komet
; meteoric showers -- code/interval/maximum/number/radiant/velocity/comet
;
;  [Configuration following below]
;
; (C)opyright Claus-Peter R"uckemann, 1996, 1999
;
; You may use the data provided here on your own risk.
; If you do use the data in any publication, program or product other than
; gcal under GPL, you have to cite where most of the sample data hacked in
; here comes from:
;
; @BOOK{Rueckemann:1999:Astronomie,
;   author = {R{\"u}ckemann, C.-P.},
;   title = {Datensammlung zur Astronomie},
;   publisher = {in Vorbereitung, M{\"u}nster},
;   year = {1999},
;   } % =:-) end of commercial for the unpublished
;
; In most cases meteoric showers do not last for long astronomical time
; intervals. Most of the material that we see 'glowing' when watching such
; showers results from the Oort's Cloud. Earlier in the history of the universe
; larger bodies impacted into the Oort's Cloud and set a huge number of
; smaller broken particles and other material free. These smaller bodies do
; carry big amounts of dust in their trail when traveling with through space at
; high speeds. If some of these smaller bodies get near the outer atmosphere
; of the earth the dust particles begin to glow while burning due to the
; heat they produce from the contact with the gases of the atmosphere.
; This way you might get some impression why meteoric showers do tend to
; be not as stable in their occurance when earth is passing their way
; on it's orbit around the sun over the years as one might suggest.
; It is known that the occourance of specific showers will vary in different
; years. It is known that some showers only happen to last for less than an
; hour each year while others do continue for several days. And we know that
; in general meteoric showers did have been much more numerous in earlier times
; of earth's history long ago ...
;
;
; The samples given do include some minor showers and there are a lot other
; minor showers and some other data missing and that most showers are only
; constant in date and brightness every year for about several decades and that
; the weather on earth might make them invisible from earth in some years,
; not to mention that in a specific year your location might not have
; dark night when the maximum occurs ... [many more]
;
; If you have any further corrections, improvements, more detailed or
; more correct data or even donations please contact:
; ruckema@uni-muenster.de
;
; 19991121 CPR Added international 3-letter-codes.
;
;------------------------ Konfiguration / configuration ----------------------
; Please notice that there are tabstops following some $?=~... entries!
; So use an editor that does not delete the tabs when configuring this file.
; This file is 8 bit -- modify for your codepage if needed.
;....................................german...................................
$c=~erzeugender Komet:
$d=~internationaler Code:
$m=~%1Maximum der Fallhäufigkeit%2
$n=~maximale Anzahl von Objekten:
$r=~Lage des Radianten:
$s=-Meteorstrom
$v=~mittl. Geschw. rel. Erde:
$x=den
$y=variabel
$j=Nördliche
$k=Südliche
;................................anglo-american...............................
;$c=~producing comet:
;$d=~international 3-letter-code:
;$m=~%1maximum of falling%2
;$n=~maximal number of objects:
;$r=~position of radiant:
;$s=-meteoric shower
;$v=~mean velocity rel. to earth:
;$x=ds
;$y=variable
;$j=Northern
;$k=Southern
;-----------------------------------------------------------------------------

$t=%3Zeta Aurigi$x%4$s, $m
00000101 $t
00001231 $t

00000101#0104 %e00000103#00000103 %3Quadranti$x%4$s, $d QUA, $r Bootes/Bootids, $n 45/h, $v 42.7 km/s
00000103      %3Quadranti$x%4$s, $d QUA, $r Bootes/Bootids, $m, $n 45/h, $v 42.7 km/s

00000113#0117 %3Jan. Draconi$x%4$s, $d GIA, $r Drache/Dragon, $m

00000113#0213 %3Alpha Leoni$x%4$s, $d LEO, $m

00000205#0210 %3Aurigi$x%4$s, $d AUR, $m

00000208#0209 %3Beta Centauri$x%4$s, $m

00000222#0223 %3Delta Leoni$x%4$s, $d DLE, $m

00000225#0226 %3Sigma Leoni$x%4$s, $d LEO, $m

00000401#0499 %3Virgini$x%4$s, $r Jungfrau/Virgin

00000418#0424 %e00000422#00000422 %3Lyri$x%4$s, $d LYR, $r Leier/Lyra
00000422      %3Lyri$x%4$s, $d LYR, $r Leier/Lyra, $m

00000420#0730 %e00000614#00000614 %3Scorpius-Sagittarii$x%4$s, $r Skorpion-Schütze/Scorpio-Sagittarius, $n 6/h
00000614      %3Scorpius-Sagittarii$x%4$s, $r Skorpion-Schütze/Scorpio-Sagittarius, $m, $n 6/h

00000429#0521 %e00000505#00000505 %3Eta Aquari$x%4$s, $d ETA, $r Wassermann/Aquarius, $n 40/h, $v 64 km/s, $c Halley
00000505      %3Eta Aquari$x%4$s, $d ETA, $r Wassermann/Aquarius, $m, $n 40/h, $v 64 km/s, $c Halley

00000627#0705 %e00000628#00000628 %3Jun. Booti$x%4$s, $r Bootes/Bootids
00000628      %3Jun. Booti$x%4$s, $r Bootes/Bootids, $m

00000725#0810 %e00000803#00000803 %3Delta Aquari$x%4$s, $d NDA/SDA, $r Wassermann/Aquarius, $n 12/h, $v 30 km/s
00000803      %3Delta Aquari$x%4$s, $d NDA/SDA, $r Wassermann/Aquarius, $m, $n 12/h, $v 30 km/s

00000720#0819 %e00000811#00000812 %3Persei$x%4$s, $d PER, $r Perseus/Perseides, $n 100/h, $v 60.4 km/s, $c 1862 III
00000811#0812 %3Persei$x%4$s, $d PER, $r Perseus/Perseides, $m, $n 100/h, $v 60.4 km/s, $c 1862 III

00000725#0908 %e00000816#00000816 %3Cygni$x%4$s, $r Schwan/Swan, $n 5/h, $v 26.6 km/s
00000816      %3Cygni$x%4$s, $r Schwan/Swan, $m, $n 5/h, $v 26.6 km/s

00000801#0802 %3Alpha Capricorni$x%4$s, $d CAP, $m

00000806#0807 %3$k Iota Aquari$x%4$s, $d NIA/SIA, $r Wassermann/Aquarius, $m

00000818      %3Cephei$x%4$s, $r Cepheus/Cepheides, $m, $n 3/h

00000816#1008 %e00000912#00000912 %3Pisci$x%4$s, $d SPI, $r Fische/Pisces, $n 5/h
00000912      %3Pisci$x%4$s, $d SPI, $r Fische/Pisces, $m, $n 5/h

00000825#0826 %3$j Iota Aquari$x%4$s, $d NIA/SIA, $r Wassermann/Aquarius, $m

00000911#0920 %3$k Pisci$x%4$s, $d SPI, $m

00000912#0913 %3Eta Draconi$x%4$s, $d GIA, $m

00000923#0924 %3Gamma Pisci$x%4$s, $d SPI, $m

00001008#1010 %e00001009#00001009 %3Oct. Draconi$x%4$s, $d GIA, $r Drache/Dragon, $n $y, $v 23.1 km/s, $c Giacobini-Zinner
00001009      %3Oct. Draconi$x%4$s, $d GIA, $r Drache/Dragon, $m, $n $y, $v 23.1 km/s, $c Giacobini-Zinner

00001011#1030 %e00001019#00001022 %3Orioni$x%4$s, $d ORI, $r Orion/Orion, $n 15/h, $v 66.5 km/s, $c Halley
00001019#1022 %3Orioni$x%4$s, $d ORI, $r Orion/Orion, $m, $n 15/h, $v 66.5 km/s, $c Halley

00001101#1110 %3Tauri$x%4$s, $d NTA/STA, $r Widder-Stier/Aries-Taurus

00001114#1120 %e00001117#00001118 %3Leoni$x%4$s, $d LEO, $r Löwe/Lion, $n $y, $v 72.0 km/s, $c 1866 I
00001117#1118 %3Leoni$x%4$s, $d LEO, $r Löwe/Lion, $m, $n $y, $v 72.0 km/s, $c 1866 I

00001205#1219 %e00001212#00001214 %3Gemini$x%4$s, $d GEM, $r Zwillinge/Gemini, $n 15/h, $v 36.5 km/h
00001212#1214 %3Gemini$x%4$s, $d GEM, $r Zwillinge/Gemini, $m, $n 15/h, $v 36.5 km/h

$t=%e00000113#00000117 %3Delta Cancri$x%4$s, $d DCA, $r Krebs/Cancer
00001214#9999 $t
00000101#0214 $t
00000113#0117 %3Delta Cancri$x%4$s, $d DCA, $r Krebs/Cancer, $m

00001217#1224 %e00001222#00001223 %3Ursi$x%4$s, $d URS
00001222#1223 %3Ursi$x%4$s, $d URS, $m

;;EOF:
