; One column world time table for Gcal-2.20 or newer
;
; $Id: wtt2.rc 0.01 2000/03/05 00:00:01 tom Exp $
;
; Copyright (c) 2000   Thomas Esken      <esken@uni-muenster.de>
;                      Im Hagenfeld 84
;                      D-48147 M"unster
;                      GERMANY
;
; This software doesn't claim completeness, correctness or usability.
; On principle I will not be liable for ANY damages or losses (implicit
; or explicit), which result from using or handling my software.
; If you use this software, you agree without any exception to this
; agreement, which binds you LEGALLY !!
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the `GNU General Public License' as published by
; the `Free Software Foundation'; either version 3, or (at your option)
; any later version.
;
; You should have received a copy of the `GNU General Public License'
; along with this program; if not, write to the:
;
;
;
; Try this resource file by using the  `-QUx'  option of Gcal.
;
; *** If you modify this file you have to rename the modified version.
; *** If you make any improvements I would like to hear from you.
; *** But I do not promise any support.
;
; Either set `$f' to `%@' or to `%@*'
; for displaying using the 12-hours time format.
;
$f=%@
;$f=%@*
;
; The line templates.
;
$p=0*d1#999
$a=$f$t  local time, $l
;
; The locations.
;
$l=Samoa
$t=-660
$p $a
;
$l=Honolulu
$t=-600
$p $a
;
$l=Anchorage
$t=-540
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=San Francisco
$t=-480
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Denver
$t=-420
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Managua
$t=-300
$p $a
;
$l=Chicago
$t=-360
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Montreal
$t=-300
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=New York
$t=-300
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Bermuda
$t=-240
a=04sun1
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Rio de Janeiro
$t=-180
a=02sat2
b=10sun1
$p %i0@a#0@b-1 $a
$t+=60
$p %e0@a#0@b-1 $a
;
$l=Azores
$t=-60
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Dakar
$t=0
$p $a
;
$l=London
$t=0
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Lisbon
$t=0
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=%3%1Münster%2
$t=60
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Madrid
$t=60
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Stockholm
$t=60
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Johannesburg
$t=120
$p $a
;
$l=Istanbul
$t=120
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Helsinki
$t=120
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Athens
$t=120
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Nairobi
$t=180
$p $a
;
$l=Moscow
$t=180
a=03sun9
b=10sun9
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Tehran
$t=210
a=0321
b=0922
$p %e0@a#0@b-1 $a
$t+=60
$p %i0@a#0@b-1 $a
;
$l=Bombay
$t=330
$p $a
;
$l=Bangkok
$t=420
$p $a
;
$l=Beijing
$t=480
$p $a
;
$l=Hongkong
$t=480
$p $a
;
$l=Tokyo
$t=540
$p $a
;
$l=Seoul
$t=540
$p $a
;
$l=Sydney
$t=600
a=03sun9
b=10sun9
$p %i0@a#0@b-1 $a
$t+=60
$p %e0@a#0@b-1 $a
;
$l=Wellington
$t=720
a=03sun3
b=10sun1
$p %i0@a#0@b-1 $a
$t+=60
$p %e0@a#0@b-1 $a
