; Sun and Moon rise/set/twilights for Münster, GERMANY, for Gcal-2.20 or newer
;
; $Id: ms.rc 0.03 2000/06/30 00:00:03 tom Exp $
;
; Copyright (c) 2000   Thomas Esken      <esken@gmx.net>
;                      Im Hagenfeld 84
;                      D-48147 M"unster
;                      GERMANY
;
; This software doesn't claim completeness, correctness or usability.
; On principle I will not be liable for ANY damages or losses (implicit
; or explicit), which result from using or handling my software.
; If you use this software, you agree without any exception to this
; agreement, which binds you LEGALLY !!
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the `GNU General Public License' as published by
; the `Free Software Foundation'; either version 3, or (at your option)
; any later version.
;
; You should have received a copy of the `GNU General Public License'
; along with this program; if not, write to the:
;
;
;
; Try `--precise' to display data and times more precise!
;
; *** If you modify this file you have to rename the modified version.
; *** If you make any improvements I would like to hear from you.
; *** But I do not promise any support.
;
;
; Line templates
;
$p=0*d1#999
;
; The Germans use Daylight Saving times,
; so it is necessary to define them explicitly
;
; Definitions for summer time
;
$t=Sun: $c,$s/$l/%:02*.$s :%:02*/$s %"$s
$m=Moon: $c,$s/$l/%:02*.$s :%:02*/$s %"$s
a=03sun9
$s=+120
$a=%i0@a#0@b-1
;
$x=$t ~\
9 > %o9$c,$s    %u9$c,$s ~\
8 > %o8$c,$s    %u8$c,$s ~\
7 > %o7$c,$s    %u7$c,$s ~\
6 > %o6$c,$s    %u6$c,$s ~\
5 * %o5$c,$s    %u5$c,$s  %oL$c,$s ~\
4 > %o4$c,$s    %u4$c,$s ~\
x2> %oQ$c,$s    %uQ$c,$s ~\
x1> %oR$c,$s    %uR$c,$s ~\
1 = %o1$c,$s  %oJ$c,$s ~\
x1< %sR$c,$s    %zR$c,$s ~\
x2< %sQ$c,$s    %zQ$c,$s ~\
4 < %s4$c,$s    %z4$c,$s ~\
5 * %s5$c,$s    %z5$c,$s  %sL$c,$s ~\
6 < %s6$c,$s    %z6$c,$s ~\
7 < %s7$c,$s    %z7$c,$s ~\
8 < %s8$c,$s    %z8$c,$s ~\
9 < %s9$c,$s    %z9$c,$s ~\
0 = %s0$c,$s  %sI$c,$s ~\
$m ~\
5 * %(5$c,$s    %[5$c,$s  %(Q$c,$s  %(*R$c,$s % ~\
4 > %(4$c,$s    %[4$c,$s ~\
1 = %)1$c,$s  %)N$c,$s  %)*O$c,$s % ~\
4 < %)4$c,$s    %]4$c,$s ~\
5 * %)5$c,$s    %]5$c,$s  %)Q$c,$s  %)*R$c,$s % ~\
0 = %(0$c,$s  %(L$c,$s  %(*M$c,$s %
;
; Definitions for winter time
;
$t=Sun: $c,$w/$l/%:02*.$w :%:02*/$w %"$w
$m=Moon: $c,$w/$l/%:02*.$w :%:02*/$w %"$w
b=10sun9
$w=+60
$b=%e0@a#0@b-1
;
$y=$t ~\
9 > %o9$c,$w    %u9$c,$w ~\
8 > %o8$c,$w    %u8$c,$w ~\
7 > %o7$c,$w    %u7$c,$w ~\
6 > %o6$c,$w    %u6$c,$w ~\
5 * %o5$c,$w    %u5$c,$w  %oL$c,$w ~\
4 > %o4$c,$w    %u4$c,$w ~\
x2> %oQ$c,$w    %uQ$c,$w ~\
x1> %oR$c,$w    %uR$c,$w ~\
1 = %o1$c,$w  %oJ$c,$w ~\
x1< %sR$c,$w    %zR$c,$w ~\
x2< %sQ$c,$w    %zQ$c,$w ~\
4 < %s4$c,$w    %z4$c,$w ~\
5 * %s5$c,$w    %z5$c,$w  %sL$c,$w ~\
6 < %s6$c,$w    %z6$c,$w ~\
7 < %s7$c,$w    %z7$c,$w ~\
8 < %s8$c,$w    %z8$c,$w ~\
9 < %s9$c,$w    %z9$c,$w ~\
0 = %s0$c,$w  %sI$c,$w ~\
$m ~\
5 * %(5$c,$w    %[5$c,$w  %(Q$c,$w  %(*R$c,$w % ~\
4 > %(4$c,$w    %[4$c,$w ~\
1 = %)1$c,$w  %)N$c,$w  %)*O$c,$w % ~\
4 < %)4$c,$w    %]4$c,$w ~\
5 * %)5$c,$w    %]5$c,$w  %)Q$c,$w  %)*R$c,$w % ~\
0 = %(0$c,$w  %(L$c,$w  %(*M$c,$w %
;
; Name of location and geographical co-ordinate
;
$l=%3%1Münster%2
$c=+5158+00738+61
;
; And shoot!
;
$p $a $x
$p $b $y
