; Air line distances between geographical locations for Gcal-2.20 or newer
;
; $Id: wloc.rc 0.02 2000/03/23 00:00:02 tom Exp $
;
; Copyright (c) 2000   Thomas Esken      <esken@uni-muenster.de>
;                      Im Hagenfeld 84
;                      D-48147 M"unster
;                      GERMANY
;
; This software doesn't claim completeness, correctness or usability.
; On principle I will not be liable for ANY damages or losses (implicit
; or explicit), which result from using or handling my software.
; If you use this software, you agree without any exception to this
; agreement, which binds you LEGALLY !!
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the `GNU General Public License' as published by
; the `Free Software Foundation'; either version 3, or (at your option)
; any later version.
;
; You should have received a copy of the `GNU General Public License'
; along with this program; if not, write to the:
;
;
;
; Try this resource file by using the  `-QUx'  option of Gcal.
; Try `--precise' to display data and times more precise!
;
; Either set your preferred geographical base location here,
; or comment the next two lines and run Gcal with the `--text-variable=ARG'
; option for passing the geographical base location in a flexible manner like:
;
;   gcal -f./wloc.rc -QUx --text-var='$a=%3%1New York%2:$b=+404151-0740023'
;
; *** If you modify this file you have to rename the modified version.
; *** If you make any improvements I would like to hear from you.
; *** But I do not promise any support.
;
$a=%3%1Münster%2
$b=+5158+00738
;
; Either set `$f' to `%>9*b0$b/$c km / %b1$b/$c' or to
;   `%>9*b*0$b/$c mi / %b1$b/$c' for displaying using statute miles.
;
$f=%>9*b0$b/$c km / %b1$b/$c
;$f=%>9*b*0$b/$c mi / %b1$b/$c
;
; The line template.
;
$x=0 $f  air line distance $a-$l
;
; The locations.
;
$l=Anchorage
$c=+611305-1495401
$x
;
$l=Athens
$c=+3758+02343
$x
;
$l=Azores
$c=+3744-02540
$x
;
$l=Bangkok
$c=+1345+10035
$x
;
$l=Beijing
$c=+3955+11620
$x
;
$l=Bermuda
$c=+3217-06446
$x
;
$l=Bombay
$c=+1855+07250
$x
;
$l=Chicago
$c=+415100-0873900
$x
;
$l=Dakar
$c=+1440-01726
$x
;
$l=Denver
$c=+394421-1045903
$x
;
$l=Helsinki
$c=+6010+02458
$x
;
$l=Hongkong
$c=+2217+11409
$x
;
$l=Honolulu
$c=+211825-1575130
$x
;
$l=Istanbul
$c=+4101+02858
$x
;
$l=Johannesburg
$c=-2615+02800
$x
;
$l=Lisbon
$c=+3843-00908
$x
;
$l=London
$c=+512830-0001845
$x
;
$l=Madrid
$c=+4024-00341
$x
;
$l=Managua
$c=+1209-08620
$x
;
$l=Montreal
$c=+4531-07334
$x
;
$l=Moscow
$c=+5545+03735
$x
;
$l=Münster
$c=+5158+00738
$x
;
$l=Nairobi
$c=-0117+03649
$x
;
$l=New York
$c=+404251-0740023
$x
;
$l=Rio de Janeiro
$c=-2300-04312
$x
;
$l=Samoa
$c=-1350-17144
$x
;
$l=San Francisco
$c=+3747-12230
$x
;
$l=Seoul
$c=+3733+12658
$x
;
$l=Stockholm
$c=+5920+01803
$x
;
$l=Sydney
$c=-3352+15113
$x
;
$l=Tehran
$c=+3540+05126
$x
;
$l=Tokyo
$c=+3542+13946
$x
;
$l=Wellington
$c=-4119+17446
$x
