; Some Sun based astronomical times and data for Gcal-2.20 or newer
;
; $Id: sdata.rc 0.07 2000/06/30 00:00:07 tom Exp $
;
; Copyright (c) 2000   Thomas Esken      <esken@gmx.net>
;                      Im Hagenfeld 84
;                      D-48147 M"unster
;                      GERMANY
;
; This software doesn't claim completeness, correctness or usability.
; On principle I will not be liable for ANY damages or losses (implicit
; or explicit), which result from using or handling my software.
; If you use this software, you agree without any exception to this
; agreement, which binds you LEGALLY !!
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the `GNU General Public License' as published by
; the `Free Software Foundation'; either version 3, or (at your option)
; any later version.
;
; You should have received a copy of the `GNU General Public License'
; along with this program; if not, write to the:
;
;
;
; Try this resource file by using the  `-QUx'  option of Gcal.
; Try `--time-offset=ARG' to calculate some data for a definite time!
; Try `--precise' to display data and times more precise!
;
; Either set your preferred geographical base location here
; or comment the proper next lines and run Gcal with the `--text-variable=ARG'
; option for passing the geographical base location in a flexible manner like:
;
;   gcal -f./sdata.rc -QUx --text-var='$l=Münster:$c=+5158+00738+61:$z=60' --time-offset=t
;
; *** If you modify this file you have to rename the modified version.
; *** If you make any improvements I would like to hear from you.
; *** But I do not promise any support.
;
;
; Name of location
; $l=%3%1Münster%2
; Geographical co-ordinate of location
; $c=+5158+00738+61
; Timezone of location
; $z=60
;
; Line templates
$p=0*d1#999
;
$l=
$c=
$z=
;
; Data.
$p A00 calculations for geographic co-ordinate          $c,$z/$l
$p A01 gmt time and date                                %@
$p A02 local time and date                              %t /%n
$p A03 given time-offset                                %ot$c
$p A04 local julian date            at %<9*ot$c         %ou$c,$z
$p A05 local julian ephemeris date  at %<9*ot$c         %ov$c,$z
$p A06 local sidereal time          at %<9*ot$c         %os$c,$z
$p A07 equation-of-time             at %<9*ot$c         %ow$c,$z
$p A08 delta-t in ss.fract          at %<9*ot$c         %or$c,$z
;
$p B00 T sun/earth distance in au   at %<9*ot$c         %of$c,$z
$p B01 T sun/earth distance in km   at %<9*ot$c         %o*f$c,$z
$p B02 T sun's ecliptic longitude   at %<9*ot$c         %od$c,$z
$p B03 T sun's right ascension      at %<9*ot$c         %oe$c,$z
$p B04 T sun's declination angle    at %<9*ot$c         %oc$c,$z
$p B05 T sun's azimuth angle        at %<9*ot$c         %ob$c,$z
$p B06 T sun's elevation angle      at %<9*ot$c         %oa$c,$z
$p B07 T sun's horizontal parallax  at %<9*ot$c         %o*g$c,$z
$p B08 T sun's semidiameter         at %<9*ot$c         %o*h$c,$z
$p B09 T sun/moon azimuth delta     at %<9*ot$c         %oy$c,$z
$p B10 T sun/moon elevation delta   at %<9*ot$c         %ox$c,$z
$p B11 T atmospheric refraction     at %<9*ot$c         %o*i$c,$z
;
$p C00 G sun/earth distance in au   at %<9*ot$c         %oo$c,$z
$p C01 G sun/earth distance in km   at %<9*ot$c         %o*o$c,$z
$p C02 G sun's ecliptic longitude   at %<9*ot$c         %om$c,$z
$p C03 G sun's right ascension      at %<9*ot$c         %on$c,$z
$p C04 G sun's declination angle    at %<9*ot$c         %ol$c,$z
$p C05 G sun's azimuth angle        at %<9*ot$c         %ok$c,$z
$p C06 G sun's elevation angle      at %<9*ot$c         %oj$c,$z
$p C07 G sun's horizontal parallax  at %<9*ot$c         %o*p$c,$z
$p C08 G sun's semidiameter         at %<9*ot$c         %o*q$c,$z
$p C09 G sun/moon azimuth delta     at %<9*ot$c         %oA$c,$z
$p C10 G sun/moon elevation delta   at %<9*ot$c         %oz$c,$z
;
$p DM0 sun's midnight (near lowest culmination) at      %o0$c,$z
$p DM2 T sun's elevation angle      at sun's midnight   %oI$c,$z
$p DM3 G sun's elevation angle      at sun's midnight   %oM$c,$z
$p DM4 sun/moon midnight delta                          %oF$c,$z
$p DN1 sun's noon (near highest culmination) at         %s1$c,$z
$p DN2 T sun's elevation angle      at sun's noon       %sJ$c,$z
$p DN3 G sun's elevation angle      at sun's noon       %sN$c,$z
$p DN4 sun/moon noon delta                              %sG$c,$z
;
$p ER0 astronomical twilight starts at                  %o9$c,$z
$p FR0 amateur-astronomers twilight starts at           %o8$c,$z
$p GR0 nautical twilight starts at                      %o7$c,$z
$p HR0 civil twilight starts at                         %o6$c,$z
$p IR0 sun's upper limb (standard rise) rises at        %o5$c,$z
$p IR3 T sun's azimuth angle        at sun's rise       %oL$c,$z
$p IR4 T sun's elevation angle      at sun's rise       %oK$c,$z
$p IR5 G sun's azimuth angle        at sun's rise       %oP$c,$z
$p IR6 G sun's elevation angle      at sun's rise       %oO$c,$z
$p IR7 T sun/moon azimuth delta     at sun's rise       %oC$c,$z
$p IR8 T sun/moon elevation delta   at sun's rise       %oB$c,$z
$p IR9 G sun/moon azimuth delta     at sun's rise       %oE$c,$z
$p IRA G sun/moon elevation delta   at sun's rise       %oD$c,$z
$p IRB sun/moon standard rise delta                     %oH$c,$z
$p JR0 sun's center rises at                            %o4$c,$z
$p KR0 sun's upper limb at math-horizon rises at        %o3$c,$z
$p LR0 sun's center at math-horizon rises at            %o2$c,$z
$p MR0 shadow length equal 2x object height at          %oQ$c,$z
$p NR0 shadow length equal 1x object height at          %oR$c,$z
;
$p NS1 shadow length equal 1x object height at          %sR$c,$z
$p MS1 shadow length equal 2x object height at          %sQ$c,$z
$p LS1 sun's center at math-horizon sets at             %s2$c,$z
$p KS1 sun's upper limb at math-horizon sets at         %s3$c,$z
$p JS1 sun's center sets at                             %s4$c,$z
$p IS1 sun's upper limb (standard set) sets at          %s5$c,$z
$p IS3 T sun's azimuth angle        at sun's set        %sL$c,$z
$p IS4 T sun's elevation angle      at sun's set        %sK$c,$z
$p IS5 G sun's azimuth angle        at sun's set        %sP$c,$z
$p IS6 G sun's elevation angle      at sun's set        %sO$c,$z
$p IS7 T sun/moon azimuth delta     at sun's set        %sC$c,$z
$p IS8 T sun/moon elevation delta   at sun's set        %sB$c,$z
$p IS9 G sun/moon azimuth delta     at sun's set        %sE$c,$z
$p ISA G sun/moon elevation delta   at sun's set        %sD$c,$z
$p ISB sun/moon standard set delta                      %sH$c,$z
$p HS1 civil twilight ends at                           %s6$c,$z
$p GS1 nautical twilight ends at                        %s7$c,$z
$p FS1 amateur-astronomers twilight ends at             %s8$c,$z
$p ES1 astronomical twilight ends at                    %s9$c,$z
;
$p QE5 astronomical twilight visible                    %u9$c,$z
$p QE6 astronomical twilight non-visible                %z9$c,$z
$p QF5 amateur-astronomers twilight visible             %u8$c,$z
$p QF6 amateur-astronomers twilight non-visible         %z8$c,$z
$p QG5 nautical twilight visible                        %u7$c,$z
$p QG6 nautical twilight non-visible                    %z7$c,$z
$p QH5 civil twilight visible                           %u6$c,$z
$p QH6 civil twilight non-visible                       %z6$c,$z
$p QI5 sun's upper limb (standard r/s) visible          %u5$c,$z
$p QI6 sun's upper limb (standard r/s) non-visible      %z5$c,$z
$p QJ5 sun's center visible                             %u4$c,$z
$p QJ6 sun's center non-visible                         %z4$c,$z
$p QK5 math-horizon sun's upper limb visible            %u3$c,$z
$p QK6 math-horizon sun's upper limb non-visible        %z3$c,$z
$p QL5 math-horizon sun's center visible                %u2$c,$z
$p QL6 math-horizon sun's center non-visible            %z2$c,$z
$p QM5 shadow length 2x object height visible           %uQ$c,$z
$p QM6 shadow length 2x object height non-visible       %zQ$c,$z
$p QN5 shadow length 1x object height visible           %uR$c,$z
$p QN6 shadow length 1x object height non-visible       %zR$c,$z
