; Some Sun based astronomical times and data for locations in Germany for Gcal-2.20 or newer
;
; $Id: de-sdata.rc 0.06 2000/06/30 00:00:06 tom Exp $
;
; Copyright (c) 2000   Thomas Esken      <esken@gmx.net>
;                      Im Hagenfeld 84
;                      D-48147 M"unster
;                      GERMANY
;
; This software doesn't claim completeness, correctness or usability.
; On principle I will not be liable for ANY damages or losses (implicit
; or explicit), which result from using or handling my software.
; If you use this software, you agree without any exception to this
; agreement, which binds you LEGALLY !!
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the `GNU General Public License' as published by
; the `Free Software Foundation'; either version 3, or (at your option)
; any later version.
;
; You should have received a copy of the `GNU General Public License'
; along with this program; if not, write to the:
;
;
;
; Try this resource file by using the  `-QUx'  option of Gcal.
; Try `--time-offset=ARG' to calculate some data for a definite time!
; Try `--precise' to display data and times more precise!
;
; *** If you modify this file you have to rename the modified version.
; *** If you make any improvements I would like to hear from you.
; *** But I do not promise any support.
;
;
; Name of location and geographical co-ordinate
$l=%3%1Münster%2
$c=+5158+00738+61
;
; Line templates
$p=0*d1#999
;
; Definitions for winter time
$a=%e0@a#0@b-1
;
; Winter time in Germany == CEWT/GMT-1 (+60 minutes)
$w=+60
;
; Start of winter time in Germany
b=10sun9
;
; Definitions for summer time
$b=%i0@a#0@b-1
;
; Summer time in Germany == CEST/GMT-2 (+120 minutes)
$s=+120
;
; Start of summer time in Germany
a=03sun9
;
; Data
$t=A00 calculations for geographic co-ordinate          $c
$p $a $t,$w/$l
$p $b $t,$s/$l
$p A01 gmt time and date                                %@
$p A02 local time and date                              %t /%n
$p A03 given time-offset                                %ot$c
$t=A04 local julian date            at %<9*ot$c         %ou$c
$p $a $t,$w
$p $b $t,$s
$t=A05 local julian ephemeris date  at %<9*ot$c         %ov$c
$p $a $t,$w
$p $b $t,$s
$t=A06 local sidereal time          at %<9*ot$c         %os$c
$p $a $t,$w
$p $b $t,$s
$t=A07 equation-of-time             at %<9*ot$c         %ow$c
$p $a $t,$w
$p $b $t,$s
$t=A08 delta-t in ss.fract          at %<9*ot$c         %or$c
$p $a $t,$w
$p $b $t,$s
;
$t=B00 T sun/earth distance in au   at %<9*ot$c         %of$c
$p $a $t,$w
$p $b $t,$s
$t=B01 T sun/earth distance in km   at %<9*ot$c         %o*f$c
$p $a $t,$w
$p $b $t,$s
$t=B02 T sun's ecliptic longitude   at %<9*ot$c         %od$c
$p $a $t,$w
$p $b $t,$s
$t=B03 T sun's right ascension      at %<9*ot$c         %oe$c
$p $a $t,$w
$p $b $t,$s
$t=B04 T sun's declination angle    at %<9*ot$c         %oc$c
$p $a $t,$w
$p $b $t,$s
$t=B05 T sun's azimuth angle        at %<9*ot$c         %ob$c
$p $a $t,$w
$p $b $t,$s
$t=B06 T sun's elevation angle      at %<9*ot$c         %oa$c
$p $a $t,$w
$p $b $t,$s
$t=B07 T sun's horizontal parallax  at %<9*ot$c         %o*g$c
$p $a $t,$w
$p $b $t,$s
$t=B08 T sun's semidiameter         at %<9*ot$c         %o*h$c
$p $a $t,$w
$p $b $t,$s
$t=B09 T sun/moon azimuth delta     at %<9*ot$c         %oy$c
$p $a $t,$w
$p $b $t,$s
$t=B10 T sun/moon elevation delta   at %<9*ot$c         %ox$c
$p $a $t,$w
$p $b $t,$s
$t=B11 T atmospheric refraction     at %<9*ot$c         %o*i$c
$p $a $t,$w
$p $b $t,$s
;
$t=C00 G sun/earth distance in au   at %<9*ot$c         %oo$c
$p $a $t,$w
$p $b $t,$s
$t=C01 G sun/earth distance in km   at %<9*ot$c         %o*o$c
$p $a $t,$w
$p $b $t,$s
$t=C02 G sun's ecliptic longitude   at %<9*ot$c         %om$c
$p $a $t,$w
$p $b $t,$s
$t=C03 G sun's right ascension      at %<9*ot$c         %on$c
$p $a $t,$w
$p $b $t,$s
$t=C04 G sun's declination angle    at %<9*ot$c         %ol$c
$p $a $t,$w
$p $b $t,$s
$t=C05 G sun's azimuth angle        at %<9*ot$c         %ok$c
$p $a $t,$w
$p $b $t,$s
$t=C06 G sun's elevation angle      at %<9*ot$c         %oj$c
$p $a $t,$w
$p $b $t,$s
$t=C07 G sun's horizontal parallax  at %<9*ot$c         %o*p$c
$p $a $t,$w
$p $b $t,$s
$t=C08 G sun's semidiameter         at %<9*ot$c         %o*q$c
$p $a $t,$w
$p $b $t,$s
$t=C09 G sun/moon azimuth delta     at %<9*ot$c         %oA$c
$p $a $t,$w
$p $b $t,$s
$t=C10 G sun/moon elevation delta   at %<9*ot$c         %oz$c
$p $a $t,$w
$p $b $t,$s
;
$t=DM0 sun's midnight (near lowest culmination) at      %o0$c
$p $a $t,$w
$p $b $t,$s
$t=DM2 T sun's elevation angle      at sun's midnight   %oI$c
$p $a $t,$w
$p $b $t,$s
$t=DM3 G sun's elevation angle      at sun's midnight   %oM$c
$p $a $t,$w
$p $b $t,$s
$t=DM4 sun/moon midnight delta                          %oF$c
$p $a $t,$w
$p $b $t,$s
$t=DN1 sun's noon (near highest culmination) at         %s1$c
$p $a $t,$w
$p $b $t,$s
$t=DN2 T sun's elevation angle      at sun's noon       %sJ$c
$p $a $t,$w
$p $b $t,$s
$t=DN3 G sun's elevation angle      at sun's noon       %sN$c
$p $a $t,$w
$p $b $t,$s
$t=DN4 sun/moon noon delta                              %sG$c
$p $a $t,$w
$p $b $t,$s
;
$t=ER0 astronomical twilight starts at                  %o9$c
$p $a $t,$w
$p $b $t,$s
$t=FR0 amateur-astronomers twilight starts at           %o8$c
$p $a $t,$w
$p $b $t,$s
$t=GR0 nautical twilight starts at                      %o7$c
$p $a $t,$w
$p $b $t,$s
$t=HR0 civil twilight starts at                         %o6$c
$p $a $t,$w
$p $b $t,$s
$t=IR0 sun's upper limb (standard rise) rises at        %o5$c
$p $a $t,$w
$p $b $t,$s
$t=IR3 T sun's azimuth angle        at sun's rise       %oL$c
$p $a $t,$w
$p $b $t,$s
$t=IR4 T sun's elevation angle      at sun's rise       %oK$c
$p $a $t,$w
$p $b $t,$s
$t=IR5 G sun's azimuth angle        at sun's rise       %oP$c
$p $a $t,$w
$p $b $t,$s
$t=IR6 G sun's elevation angle      at sun's rise       %oO$c
$p $a $t,$w
$p $b $t,$s
$t=IR7 T sun/moon azimuth delta     at sun's rise       %oC$c
$p $a $t,$w
$p $b $t,$s
$t=IR8 T sun/moon elevation delta   at sun's rise       %oB$c
$p $a $t,$w
$p $b $t,$s
$t=IR9 G sun/moon azimuth delta     at sun's rise       %oE$c
$p $a $t,$w
$p $b $t,$s
$t=IRA G sun/moon elevation delta   at sun's rise       %oD$c
$p $a $t,$w
$p $b $t,$s
$t=IRB sun/moon standard rise delta                     %oH$c
$p $a $t,$w
$p $b $t,$s
$t=JR0 sun's center rises at                            %o4$c
$p $a $t,$w
$p $b $t,$s
$t=KR0 sun's upper limb at math-horizon rises at        %o3$c
$p $a $t,$w
$p $b $t,$s
$t=LR0 sun's center at math-horizon rises at            %o2$c
$p $a $t,$w
$p $b $t,$s
$t=MR0 shadow length equal 2x object height at          %oQ$c
$p $a $t,$w
$p $b $t,$s
$t=NR0 shadow length equal 1x object height at          %oR$c
$p $a $t,$w
$p $b $t,$s
;
$t=NS1 shadow length equal 1x object height at          %sR$c
$p $a $t,$w
$p $b $t,$s
$t=MS1 shadow length equal 2x object height at          %sQ$c
$p $a $t,$w
$p $b $t,$s
$t=LS1 sun's center at math-horizon sets at             %s2$c
$p $a $t,$w
$p $b $t,$s
$t=KS1 sun's upper limb at math-horizon sets at         %s3$c
$p $a $t,$w
$p $b $t,$s
$t=JS1 sun's center sets at                             %s4$c
$p $a $t,$w
$p $b $t,$s
$t=IS1 sun's upper limb (standard set) sets at          %s5$c
$p $a $t,$w
$p $b $t,$s
$t=IS3 T sun's azimuth angle        at sun's set        %sL$c
$p $a $t,$w
$p $b $t,$s
$t=IS4 T sun's elevation angle      at sun's set        %sK$c
$p $a $t,$w
$p $b $t,$s
$t=IS5 G sun's azimuth angle        at sun's set        %sP$c
$p $a $t,$w
$p $b $t,$s
$t=IS6 G sun's elevation angle      at sun's set        %sO$c
$p $a $t,$w
$p $b $t,$s
$t=IS7 T sun/moon azimuth delta     at sun's set        %sC$c
$p $a $t,$w
$p $b $t,$s
$t=IS8 T sun/moon elevation delta   at sun's set        %sB$c
$p $a $t,$w
$p $b $t,$s
$t=IS9 G sun/moon azimuth delta     at sun's set        %sE$c
$p $a $t,$w
$p $b $t,$s
$t=ISA G sun/moon elevation delta   at sun's set        %sD$c
$p $a $t,$w
$p $b $t,$s
$t=ISB sun/moon standard set delta                      %sH$c
$p $a $t,$w
$p $b $t,$s
$t=HS1 civil twilight ends at                           %s6$c
$p $a $t,$w
$p $b $t,$s
$t=GS1 nautical twilight ends at                        %s7$c
$p $a $t,$w
$p $b $t,$s
$t=FS1 amateur-astronomers twilight ends at             %s8$c
$p $a $t,$w
$p $b $t,$s
$t=ES1 astronomical twilight ends at                    %s9$c
$p $a $t,$w
$p $b $t,$s
;
$t=QE5 astronomical twilight visible                    %u9$c
$p $a $t,$w
$p $b $t,$s
$t=QE6 astronomical twilight non-visible                %z9$c
$p $a $t,$w
$p $b $t,$s
$t=QF5 amateur-astronomers twilight visible             %u8$c
$p $a $t,$w
$p $b $t,$s
$t=QF6 amateur-astronomers twilight non-visible         %z8$c
$p $a $t,$w
$p $b $t,$s
$t=QG5 nautical twilight visible                        %u7$c
$p $a $t,$w
$p $b $t,$s
$t=QG6 nautical twilight non-visible                    %z7$c
$p $a $t,$w
$p $b $t,$s
$t=QH5 civil twilight visible                           %u6$c
$p $a $t,$w
$p $b $t,$s
$t=QH6 civil twilight non-visible                       %z6$c
$p $a $t,$w
$p $b $t,$s
$t=QI5 sun's upper limb (standard r/s) visible          %u5$c
$p $a $t,$w
$p $b $t,$s
$t=QI6 sun's upper limb (standard r/s) non-visible      %z5$c
$p $a $t,$w
$p $b $t,$s
$t=QJ5 sun's center visible                             %u4$c
$p $a $t,$w
$p $b $t,$s
$t=QJ6 sun's center non-visible                         %z4$c
$p $a $t,$w
$p $b $t,$s
$t=QK5 math-horizon sun's upper limb visible            %u3$c
$p $a $t,$w
$p $b $t,$s
$t=QK6 math-horizon sun's upper limb non-visible        %z3$c
$p $a $t,$w
$p $b $t,$s
$t=QL5 math-horizon sun's center visible                %u2$c
$p $a $t,$w
$p $b $t,$s
$t=QL6 math-horizon sun's center non-visible            %z2$c
$p $a $t,$w
$p $b $t,$s
$t=QM5 shadow length 2x object height visible           %uQ$c
$p $a $t,$w
$p $b $t,$s
$t=QM6 shadow length 2x object height non-visible       %zQ$c
$p $a $t,$w
$p $b $t,$s
$t=QN5 shadow length 1x object height visible           %uR$c
$p $a $t,$w
$p $b $t,$s
$t=QN6 shadow length 1x object height non-visible       %zR$c
$p $a $t,$w
$p $b $t,$s
