; Some Moon based astronomical times and data for locations in Germany for Gcal-2.20 or newer
;
; $Id: de-mdata.rc 0.06 2000/06/30 00:00:06 tom Exp $
;
; Copyright (c) 2000   Thomas Esken      <esken@gmx.net>
;                      Im Hagenfeld 84
;                      D-48147 M"unster
;                      GERMANY
;
; This software doesn't claim completeness, correctness or usability.
; On principle I will not be liable for ANY damages or losses (implicit
; or explicit), which result from using or handling my software.
; If you use this software, you agree without any exception to this
; agreement, which binds you LEGALLY !!
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the `GNU General Public License' as published by
; the `Free Software Foundation'; either version 3, or (at your option)
; any later version.
;
; You should have received a copy of the `GNU General Public License'
; along with this program; if not, write to the:
;
;
;
; Try this resource file by using the  `-QUx'  option of Gcal.
; Try `--time-offset=ARG' to calculate some data for a definite time!
; Try `--precise' to display data and times more precise!
;
; *** If you modify this file you have to rename the modified version.
; *** If you make any improvements I would like to hear from you.
; *** But I do not promise any support.
;
;
; Name of location and geographical co-ordinate
$l=%3%1Münster%2
$c=+5158+00738+61
;
; Line templates
$p=0*d1#999
;
; Definitions for winter time
$a=%e0@a#0@b-1
;
; Winter time in Germany == CEWT/GMT-1 (+60 minutes)
$w=+60
;
; Start of winter time in Germany
b=10sun9
;
; Definitions for summer time
$b=%i0@a#0@b-1
;
; Summer time in Germany == CEST/GMT-2 (+120 minutes)
$s=+120
;
; Start of summer time in Germany
a=03sun9
;
; Data
$t=A00 calculations for geographic co-ordinate          $c
$p $a $t,$w/$l
$p $b $t,$s/$l
$p A01 gmt time and date                                %@
$p A02 local time and date                              %t /%n
$p A03 given time-offset                                %(x$c
$t=A04 local julian date            at %<9*(x$c         %(y$c
$p $a $t,$w
$p $b $t,$s
$t=A05 local julian ephemeris date  at %<9*(x$c         %(z$c
$p $a $t,$w
$p $b $t,$s
$t=A06 local sidereal time          at %<9*(x$c         %(w$c
$p $a $t,$w
$p $b $t,$s
$t=A07 delta-t in ss.fract          at %<9*(x$c         %(v$c
$p $a $t,$w
$p $b $t,$s
;
$t=B00 T moon/earth dist in radii   at %<9*(x$c         %(g$c
$p $a $t,$w
$p $b $t,$s
$t=B01 T moon/earth dist in km      at %<9*(x$c         %(*g$c
$p $a $t,$w
$p $b $t,$s
$t=B02 T moon's ecliptic longitude  at %<9*(x$c         %(d$c
$p $a $t,$w
$p $b $t,$s
$t=B03 T moon's ecliptic latitude   at %<9*(x$c         %(e$c
$p $a $t,$w
$p $b $t,$s
$t=B04 T moon's right ascension     at %<9*(x$c         %(f$c
$p $a $t,$w
$p $b $t,$s
$t=B05 T moon's declination angle   at %<9*(x$c         %(c$c
$p $a $t,$w
$p $b $t,$s
$t=B06 T moon's azimuth angle       at %<9*(x$c         %(b$c
$p $a $t,$w
$p $b $t,$s
$t=B07 T moon's elevation angle     at %<9*(x$c         %(a$c
$p $a $t,$w
$p $b $t,$s
$t=B08 T moon's horizontal parallax at %<9*(x$c         %(*6$c
$p $a $t,$w
$p $b $t,$s
$t=B09 T moon's semidiameter        at %<9*(x$c         %(*7$c
$p $a $t,$w
$p $b $t,$s
$t=B10 T moon's magnitude           at %<9*(x$c         %(8$c
$p $a $t,$w
$p $b $t,$s
$t=B11 T moon's phase angle         at %<9*(x$c         %(9$c
$p $a $t,$w
$p $b $t,$s
$t=B12 T moon/sun elongation        at %<9*(x$c         %(h$c
$p $a $t,$w
$p $b $t,$s
$t=B13 T moon/sun azimuth delta     at %<9*(x$c         %(B$c
$p $a $t,$w
$p $b $t,$s
$t=B14 T moon/sun elevation delta   at %<9*(x$c         %(A$c
$p $a $t,$w
$p $b $t,$s
$t=B15 T atmospheric refraction     at %<9*(x$c         %(*i$c
$p $a $t,$w
$p $b $t,$s
;
$t=C00 G moon/earth dist in radii   at %<9*(x$c         %(t$c
$p $a $t,$w
$p $b $t,$s
$t=C01 G moon/earth dist in km      at %<9*(x$c         %(*t$c
$p $a $t,$w
$p $b $t,$s
$t=C02 G moon's ecliptic longitude  at %<9*(x$c         %(q$c
$p $a $t,$w
$p $b $t,$s
$t=C03 G moon's ecliptic latitude   at %<9*(x$c         %(r$c
$p $a $t,$w
$p $b $t,$s
$t=C04 G moon's right ascension     at %<9*(x$c         %(s$c
$p $a $t,$w
$p $b $t,$s
$t=C05 G moon's declination angle   at %<9*(x$c         %(p$c
$p $a $t,$w
$p $b $t,$s
$t=C06 G moon's azimuth angle       at %<9*(x$c         %(o$c
$p $a $t,$w
$p $b $t,$s
$t=C07 G moon's elevation angle     at %<9*(x$c         %(n$c
$p $a $t,$w
$p $b $t,$s
$t=C08 G moon's horizontal parallax at %<9*(x$c         %(*j$c
$p $a $t,$w
$p $b $t,$s
$t=C09 G moon's semidiameter        at %<9*(x$c         %(*k$c
$p $a $t,$w
$p $b $t,$s
$t=C10 G moon's magnitude           at %<9*(x$c         %(l$c
$p $a $t,$w
$p $b $t,$s
$t=C11 G moon's phase angle         at %<9*(x$c         %(m$c
$p $a $t,$w
$p $b $t,$s
$t=C12 G moon/sun elongation        at %<9*(x$c         %(u$c
$p $a $t,$w
$p $b $t,$s
$t=C13 G moon/sun azimuth delta     at %<9*(x$c         %(D$c
$p $a $t,$w
$p $b $t,$s
$t=C14 G moon/sun elevation delta   at %<9*(x$c         %(C$c
$p $a $t,$w
$p $b $t,$s
;
$t=DM0 moon's midnight (near lowest culmination) at     %(0$c
$p $a $t,$w
$p $b $t,$s
$t=DM2 T moon's elevation angle     at moon's midnight  %(L$c
$p $a $t,$w
$p $b $t,$s
$t=DM3 T moon's phase angle         at moon's midnight  %(M$c
$p $a $t,$w
$p $b $t,$s
$t=DM4 G moon's elevation angle     at moon's midnight  %(S$c
$p $a $t,$w
$p $b $t,$s
$t=DM5 G moon's phase angle         at moon's midnight  %(T$c
$p $a $t,$w
$p $b $t,$s
$t=DM6 moon/sun midnight delta                          %(I$c
$p $a $t,$w
$p $b $t,$s
$t=DN1 moon's noon (near highest culmination) at        %)1$c
$p $a $t,$w
$p $b $t,$s
$t=DN2 T moon's elevation angle     at moon's noon      %)N$c
$p $a $t,$w
$p $b $t,$s
$t=DN3 T moon's phase angle         at moon's noon      %)O$c
$p $a $t,$w
$p $b $t,$s
$t=DN4 G moon's elevation angle     at moon's noon      %)U$c
$p $a $t,$w
$p $b $t,$s
$t=DN5 G moon's phase angle         at moon's noon      %)V$c
$p $a $t,$w
$p $b $t,$s
$t=DN6 moon/sun noon delta                              %)J$c
$p $a $t,$w
$p $b $t,$s
;
$t=ER0 moon's upper limb (standard rise) rises at       %(5$c
$p $a $t,$w
$p $b $t,$s
$t=ER3 T moon's azimuth angle       at moon's rise      %(Q$c
$p $a $t,$w
$p $b $t,$s
$t=ER4 T moon's elevation angle     at moon's rise      %(P$c
$p $a $t,$w
$p $b $t,$s
$t=ER5 T moon's phase angle         at moon's rise      %(R$c
$p $a $t,$w
$p $b $t,$s
$t=ER6 G moon's azimuth angle       at moon's rise      %(X$c
$p $a $t,$w
$p $b $t,$s
$t=ER7 G moon's elevation angle     at moon's rise      %(W$c
$p $a $t,$w
$p $b $t,$s
$t=ER8 G moon's phase angle         at moon's rise      %(Y$c
$p $a $t,$w
$p $b $t,$s
$t=ER9 T moon/sun azimuth delta     at moon's rise      %(F$c
$p $a $t,$w
$p $b $t,$s
$t=ERA T moon/sun elevation delta   at moon's rise      %(E$c
$p $a $t,$w
$p $b $t,$s
$t=ERB G moon/sun azimuth delta     at moon's rise      %(H$c
$p $a $t,$w
$p $b $t,$s
$t=ERC G moon/sun elevation delta   at moon's rise      %(G$c
$p $a $t,$w
$p $b $t,$s
$t=ERD moon/sun standard rise delta                     %(K$c
$p $a $t,$w
$p $b $t,$s
$t=FR0 moon's center rises at                           %(4$c
$p $a $t,$w
$p $b $t,$s
$t=GR0 moon's upper limb at math-horizon rises at       %(3$c
$p $a $t,$w
$p $b $t,$s
$t=HR0 moon's center at math-horizon rises at           %(2$c
$p $a $t,$w
$p $b $t,$s
;
$t=HS1 moon's center at math-horizon sets at            %)2$c
$p $a $t,$w
$p $b $t,$s
$t=GS1 moon's upper limb at math-horizon sets at        %)3$c
$p $a $t,$w
$p $b $t,$s
$t=FS1 moon's center sets at                            %)4$c
$p $a $t,$w
$p $b $t,$s
$t=ES1 moon's upper limb (standard set) sets at         %)5$c
$p $a $t,$w
$p $b $t,$s
$t=ES3 T moon's azimuth angle       at moon's set       %)Q$c
$p $a $t,$w
$p $b $t,$s
$t=ES4 T moon's elevation angle     at moon's set       %)P$c
$p $a $t,$w
$p $b $t,$s
$t=ES5 T moon's phase angle         at moon's set       %)R$c
$p $a $t,$w
$p $b $t,$s
$t=ES6 G moon's azimuth angle       at moon's set       %)X$c
$p $a $t,$w
$p $b $t,$s
$t=ES7 G moon's elevation angle     at moon's set       %)W$c
$p $a $t,$w
$p $b $t,$s
$t=ES8 G moon's phase angle         at moon's set       %)Y$c
$p $a $t,$w
$p $b $t,$s
$t=ES9 T moon/sun azimuth delta     at moon's set       %)F$c
$p $a $t,$w
$p $b $t,$s
$t=ESA T moon/sun elevation delta   at moon's set       %)E$c
$p $a $t,$w
$p $b $t,$s
$t=ESB G moon/sun azimuth delta     at moon's set       %)H$c
$p $a $t,$w
$p $b $t,$s
$t=ESC G moon/sun elevation delta   at moon's set       %)G$c
$p $a $t,$w
$p $b $t,$s
$t=ESD moon/sun standard set delta                      %)K$c
$p $a $t,$w
$p $b $t,$s
;
$t=QE6 moon's upper limb (standard r/s) visible         %[5$c
$p $a $t,$w
$p $b $t,$s
$t=QE7 moon's upper limb (standard r/s) non-visible     %]5$c
$p $a $t,$w
$p $b $t,$s
$t=QF6 moon's center visible                            %[4$c
$p $a $t,$w
$p $b $t,$s
$t=QF7 moon's center non-visible                        %]4$c
$p $a $t,$w
$p $b $t,$s
$t=QG6 math-horizon moon's upper limb visible           %[3$c
$p $a $t,$w
$p $b $t,$s
$t=QG7 math-horizon moon's upper limb non-visible       %]3$c
$p $a $t,$w
$p $b $t,$s
$t=QH6 math-horizon moon's center visible               %[2$c
$p $a $t,$w
$p $b $t,$s
$t=QH7 math-horizon moon's center non-visible           %]2$c
$p $a $t,$w
$p $b $t,$s
