; Sun and Moon rise/set/twilights for Bangkok, THAILAND, for Gcal-2.20 or newer
;
; $Id: bkk.rc 0.03 2000/06/30 00:00:03 tom Exp $
;
; Copyright (c) 2000   Thomas Esken      <esken@gmx.net>
;                      Im Hagenfeld 84
;                      D-48147 M"unster
;                      GERMANY
;
; This software doesn't claim completeness, correctness or usability.
; On principle I will not be liable for ANY damages or losses (implicit
; or explicit), which result from using or handling my software.
; If you use this software, you agree without any exception to this
; agreement, which binds you LEGALLY !!
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the `GNU General Public License' as published by
; the `Free Software Foundation'; either version 3, or (at your option)
; any later version.
;
; You should have received a copy of the `GNU General Public License'
; along with this program; if not, write to the:
;
;
;
; Try `--precise' to display data and times more precise!
;
; *** If you modify this file you have to rename the modified version.
; *** If you make any improvements I would like to hear from you.
; *** But I do not promise any support.
;
;
; Line templates
;
$p=0*d1#999
;
; The Thais do not use Daylight Saving times,
; so a simple timezone definition is necessary only
;
$t=Sun: $c,$z/$l/%:02*.$z :%:02*/$z %"$z
$m=Moon: $c,$z/$l/%:02*.$z :%:02*/$z %"$z
;
$x=$t ~\
9 > %o9$c,$z    %u9$c,$z ~\
8 > %o8$c,$z    %u8$c,$z ~\
7 > %o7$c,$z    %u7$c,$z ~\
6 > %o6$c,$z    %u6$c,$z ~\
5 * %o5$c,$z    %u5$c,$z  %oL$c,$z ~\
4 > %o4$c,$z    %u4$c,$z ~\
x2> %oQ$c,$z    %uQ$c,$z ~\
x1> %oR$c,$z    %uR$c,$z ~\
1 = %o1$c,$z  %oJ$c,$z ~\
x1< %sR$c,$z    %zR$c,$z ~\
x2< %sQ$c,$z    %zQ$c,$z ~\
4 < %s4$c,$z    %z4$c,$z ~\
5 * %s5$c,$z    %z5$c,$z  %sL$c,$z ~\
6 < %s6$c,$z    %z6$c,$z ~\
7 < %s7$c,$z    %z7$c,$z ~\
8 < %s8$c,$z    %z8$c,$z ~\
9 < %s9$c,$z    %z9$c,$z ~\
0 = %s0$c,$z  %sI$c,$z ~\
$m ~\
5 * %(5$c,$z    %[5$c,$z  %(Q$c,$z  %(*R$c,$z % ~\
4 > %(4$c,$z    %[4$c,$z ~\
1 = %)1$c,$z  %)N$c,$z  %)*O$c,$z % ~\
4 < %)4$c,$z    %]4$c,$z ~\
5 * %)5$c,$z    %]5$c,$z  %)Q$c,$z  %)*R$c,$z % ~\
0 = %(0$c,$z  %(L$c,$z  %(*M$c,$z %
;
; Name of location, geographical co-ordinate and timezone
;
$l=%3%1Bangkok%2
$c=+1345+10031+10
$z=+420
;
; And shoot!
;
$p $x
